#
# spec file for package python-uritemplate
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%bcond_without tests
Name:           python-uritemplate
Version:        4.1.1
Release:        3.4
Summary:        URI Template Expansison
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://pypi.python.org/pypi/uritemplate
Source:         https://files.pythonhosted.org/packages/source/u/uritemplate/uritemplate-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This is a Python implementation of RFC6570, URI Template, and can expand
templates up to and including Level 4 in that specification

%prep
%autosetup -p1 -n uritemplate-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python tests/test_uritemplate.py
}
%endif

%files %{python_files}
%license LICENSE LICENSE.*
%doc AUTHORS.rst HISTORY.rst README.rst
%{python_sitelib}/uritemplate
%{python_sitelib}/uritemplate-%{version}*-info

%changelog
* Sun Jun 25 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Fri Feb 10 2023 Matej Cepl <mcepl@suse.com>
- Remove completely unnecessary dependency on python-simplejson.
* Sat Nov  6 2021 Dirk Müller <dmueller@suse.com>
- update to 4.1.1:
  - Add type annotations to uritemplate and distribute them for others to use
  - Update to a modern documentation theme as well
  - Drop support for Python 2.7, 3.4, and 3.5
  - Better support number-like types as values for variables in a template
* Fri Feb  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.0.1
  * Update to Python 3.6, 3.7, and 3.8
  * Drop support for Python 2.6, 3.2, and 3.3
  * Ignore None in list argument expansion
  * Handle a list with an empty string appropriately
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon May  8 2017 toddrme2178@gmail.com
- Re-download source tarball.
* Sun May  7 2017 toddrme2178@gmail.com
- Source URL must be https.
* Mon May  1 2017 toddrme2178@gmail.com
- Fix source URL.
- Implement single-spec version.
- Add tests.
- Add licenses and other documentation files.
* Thu Oct 27 2016 rjschwei@suse.com
- Update to version 3.0.0 (bsc#1002895)
  + No upstream change entry for 2.0 -> 3.0
- From 2.0.0
  + Merge uritemplate.py into uritemplate
  + Relicense uritemplate.py as Apache 2 and BSD
- From 1.0.1
  + Fix some minor packaging problems
- From 1.0.0
  + Fix handling of Unicode values on Python 2.6 and 2.7 for urllib.quote.
  + Confirm public stable API via version number.
* Thu Feb 20 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #316168)
* Wed Feb  5 2014 rschweikert@suse.com
- Initial build
